<?php

class Fixit_Factory {

    public function __construct(){}

    /**
     *  @return Fixit - Get Theme Details.
     */
    public static function fixit_details( $args ){

        if( $args != '' and function_exists('wp_get_theme') ){
            
            if( $args === 'theme_name' ){
                return sanitize_title( wp_get_theme() );
            }elseif( $args == 'fixit_version' ){
                return wp_get_theme()->get('Version');
            }elseif( $args == 'theme_uri' ){
                return wp_get_theme()->get('ThemeURI');
            }elseif( $args == 'theme_author' ){
                wp_get_theme()->get('Author');
            }elseif( $args == 'theme_author_uri' ){
                wp_get_theme()->get('AuthorURI');
            }else{ return false; }

        }else{ return false; }
    }

    public static function fixit_framework(){

        /* FrameWord Action to Load in Theme */
        self::load_file( '/inc/framework/theme-options.php');        
        self::load_file( '/inc/framework/class-theme-init.php');
        self::load_file( '/inc/framework/class-theme-default-option.php');
        self::load_file( '/inc/framework/class-theme-interface.php');
        self::load_file( '/inc/framework/class-theme-backup-option.php');
        self::load_file( '/inc/framework/class-theme-customization.php');
    }

    /**
     *  @return Fixit - Required Plugin Installation.
     */
    public static function fixit_required_plugin_setup(){

        if( is_admin() ){
            
            self::load_file( '/inc/tgm-plugin/class-tgm-plugin-activation.php' );
            self::load_file( '/inc/tgm-plugin/required-plugin.php' );
        }
    }

    /**
     *    @return Fixit - Check if WooCommerce is active
     */
    public static function is_woocommerce_active() {
        return class_exists( 'WooCommerce' );
    }

    public static function fixit_content( $args ){

        if( $args === 'page' && $args != '' ){

            get_template_part( 'template-parts/content', 'page' );

        }elseif( $args === 'search' && $args != '' ){

            get_template_part( 'template-parts/content', 'search' );

        }elseif( $args === 'single' && $args != '' ){

            get_template_part( 'template-parts/content', 'single' );

        }elseif( $args === 'content' && $args != '' ){

            get_template_part( 'template-parts/content' );

        }elseif( $args === 'none' && $args != '' ){

            get_template_part( 'template-parts/no', 'result' );

        }elseif( $args === 'list' && $args != '' ){

            get_template_part( 'template-parts/content', 'list' );

        }else{ return false; }
    }    

    /**
     *  @return Fixit - File Path Check is exists or not.
     */
    public static function check_file_path( $get_file_path ) {
        
        if ( file_exists( get_stylesheet_directory() . $get_file_path ) ) {
            return get_stylesheet_directory() . $get_file_path;
        }
        elseif ( file_exists( get_template_directory() . $get_file_path ) ) {
            return get_template_directory() . $get_file_path;
        }
        else {
            return false;
        }
    }

    /**
     *  @return Require File.
     */
    public static function load_file( $get_file_path ) {
        require_once self::check_file_path( $get_file_path );
    }

    /**
     *  @return Fixit - Args to Retrive path
     */
    public static function fixit_directory( $args ){

        if( $args != '' ){

            if( $args === 'current' )    return trailingslashit('/inc/');
            if( $args === 'assets' )     return trailingslashit('/assets/ac-repair/');
            if( $args === 'meta-box' )   return get_template_directory_uri() . '/inc/meta-box/';
            if( $args === 'framework' )  return get_template_directory_uri() . '/inc/framework/';
            if( $args === 'widget' )     return get_template_directory_uri() . '/inc/widget/';

        }else{  return false; }
    }    

    /**
     *  @return Fixit - Current Active Theme Directory.
     */
    public static function fixit_assets(){

        return trailingslashit('/assets/ac-repair/');
    }

    /**
     *  @return Fixit - Admin Page Access Page & Slug Name.
     */
    public static function fixit_admin_page( $args ){

        if( is_admin() and $args != '' and $args === '_prefix'){
            return esc_html__( 'Fixit', 'ac-repair');
        }
        elseif( is_admin() and $args != '' and $args === '_backup_option_title'){
            return esc_html__( 'Backup Option', 'ac-repair');
        }
        elseif( is_admin() and $args != '' and $args === '_theme_option_title'){
            return esc_html__( 'Theme Option', 'ac-repair');
        }
        elseif( is_admin() and $args != '' and $args === '_select_theme_title'){
            return esc_html__( 'Select Theme', 'ac-repair');
        }
        elseif( is_admin() and $args != '' and $args === '_purchase_code_title'){
            return esc_html__( 'Product Registration', 'ac-repair');
        }
        elseif( is_admin() and $args != '' and $args === '_backup_option_slug'){
            return sanitize_title( self::fixit_admin_page( '_prefix' ). '- Backup Option' );
        }
        elseif( is_admin() and $args != '' and $args === '_theme_option_slug' ){
            return sanitize_title( self::fixit_admin_page( '_prefix' ). '- Theme Option' );
        }
        elseif( is_admin() and $args != '' and $args === '_select_theme_slug' ){
            return sanitize_title( self::fixit_admin_page( '_prefix' ). '- Select Theme' );
        }
        elseif( is_admin() and $args != '' and $args === '_purchase_code_slug' ){
            return sanitize_title( self::fixit_admin_page( '_prefix' ). '- Product Registration' );
        }
        else{  return false; }
    }    

    /**
     *  @return Fixit - Redirect Fixit Any Page.
     */
    public static function fixit_redirect_page( $args ){

        if( $args != '' and $args === 'admin_page' ){

            return 'themes.php?page=';

        }elseif( $args != '' and $args === '_theme_option_slug' ){

            wp_safe_redirect( admin_url( self::fixit_redirect_page('admin_page') . self::fixit_admin_page('_theme_option_slug') ) ); exit;

        }elseif( $args != '' and $args === '_backup_option_slug' ){

            wp_safe_redirect( admin_url( self::fixit_redirect_page('admin_page') . self::fixit_admin_page('_backup_option_slug') ) ); exit;

        }elseif( $args != '' and $args === '_select_theme_slug' ){

            wp_safe_redirect( admin_url( self::fixit_redirect_page('admin_page') . self::fixit_admin_page('_select_theme_slug') ) ); exit;

        }elseif( $args != '' and $args === '_purchase_code_slug' ){

            wp_safe_redirect( admin_url( self::fixit_redirect_page('admin_page') . self::fixit_admin_page('_purchase_code_slug') ) ); exit;

        }else{  return false; }
    }
    
    /**
     *  @return Fixit - Theme Active Then Redirect Select Demo and Install it.
     */
    public static function fixit_theme_active_actions(){

        global $pagenow;
        
        if ( is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" ){
            self::fixit_redirect_page( '_theme_option_slug' );
        }
    }

    /**
     *  @return Fixit - Register & Enqueue Styles.
     */ 
    public static function fixit_enqueue( $args, $args2 ){

        if( $args === 'style' && $args != '' ){

            if( $args2 === 'bootstrap.min' or $args2 === 'bootstrap' ){

                if( is_rtl() )
                    wp_enqueue_style( 'bootstrap-rtl', get_template_directory_uri() . '/assets/css/bootstrap/css/rtl-bootstrap.css', array(), self::fixit_details('fixit_version'), 'all' );
                else
                    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap/css/bootstrap.min.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'bootstrap-vertical-tabs' ){

                wp_enqueue_style( 'bootstrap-tabs', get_template_directory_uri() . '/assets/css/bootstrap/css/bootstrap.vertical-tabs.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'bootstrap-grid' ){

                wp_enqueue_style( 'bootstrap-grid', get_template_directory_uri() . '/assets/css/bootstrap/css/bootstrap-grid.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'fontawesome' ){

                wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/assets/css/font-awesome/css/font-awesome.min.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'stroke-gap-icons' ){

                wp_enqueue_style( 'stroke-gap-icons', get_template_directory_uri().'/assets/css/Stroke-Gap-Icons-Webfont/style.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'fontello' ){

                wp_enqueue_style( 'fontello', get_template_directory_uri().'/assets/css/fontello/css/fontello.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'magnific-popup' ){

                wp_enqueue_style( 'magnific-popup', get_template_directory_uri().'/assets/css/magnific-popup/magnific-popup.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'owl-carousel' ){

                wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/assets/css/owlcarousel/owl.carousel.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'slick' ){

                // Slick Css
                wp_enqueue_style( 'slick', get_template_directory_uri().'/assets/css/slick/css/slick.css', array(), self::fixit_details('fixit_version'), 'all' );
                // Slick Theme Css
                wp_enqueue_style( 'slick-theme', get_template_directory_uri().'/assets/css/slick/css/slick-theme.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'date-picker' ){

                wp_enqueue_style( 'date-picker', get_template_directory_uri().'/assets/css/date-picker/date-picker.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'review' ){

                wp_enqueue_style( 'review', get_template_directory_uri().'/assets/css/review/jquery.rateyo.min.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'color-picker' ){

                wp_enqueue_style( 'wp-color-picker', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'select2' ){

                /** CDN Link :  http://cdnjs.cloudflare.com/ajax/libs/select2/3.2/select2.css  **/
                wp_enqueue_style( 'select2', get_template_directory_uri().'/assets/css/select2/select2.css', array(), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'fixit_theme_style' ){

                // Theme Style 
                wp_enqueue_style( 'fixit-custom-style',  get_template_directory_uri() . self::fixit_directory( 'assets' ) . '/css/custom-style.css');
                
                if( is_rtl() ){
                    wp_enqueue_style( 'fixit-rtl-stylesheet', get_template_directory_uri() .'/rtl.css', array(), self::fixit_details('fixit_version'), 'all' );
                }else{
                    wp_enqueue_style( 'fixit-stylesheet', get_stylesheet_uri(), array(), self::fixit_details('fixit_version'), 'all' );
                }

            }else{  return false;  }

        }elseif( $args === 'script' && $args != '' ){

            if( $args2 === 'jQuery' or $args2 === 'jquery' ){

                wp_enqueue_script('jquery');
            }
            elseif( $args2 === 'bootstrap' ){

                // Bootstrap jQuery
                wp_enqueue_script( 'bootstrap', get_template_directory_uri() .'/assets/js/bootstrap/bootstrap.min.js', array('jquery'), self::fixit_details('fixit_version'), true );
            }
            elseif( $args2 === 'stick_menu' ){

                // sticky menu jQuery
                wp_enqueue_script("sticky-menu-js", get_template_directory_uri().'/assets/js/sticky-menu/jquery.sticky.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'dropdown-menu' ){

                // DropDown Menu Script
                wp_enqueue_script( 'fixit-dropdown-menu', get_template_directory_uri().'/assets/js/drop-down-menu/dropdown-menu.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'magnific-popup' ){

                // Magnific Popup library
                wp_enqueue_script( 'magnific-popup', get_template_directory_uri().'/assets/js/magnific-popup/magnific-popup.min.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
                // Magnific Popup Custom Script
                wp_enqueue_script( 'magnific-popup-script', get_template_directory_uri().'/assets/js/magnific-popup/magnific-popup-script.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'isotop' ){

                wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotop/isotope.pkgd.min.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
                wp_enqueue_script( 'isotop-script', get_template_directory_uri().'/assets/js/isotop/isotop-script.js', array( 'jquery', 'isotope' ), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'img-load' ){

                // Image Load Script
                wp_enqueue_script( 'load_image', get_template_directory_uri().'/assets/js/image-load-script/imagesloaded.pkgd.min.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'owl-carousel' ){

                // owl-script
                wp_enqueue_script( 'owl-carousel', get_template_directory_uri().'/assets/js/owlcarousel/owl.carousel.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'slick' ){

                // Slick minified jQuery
                wp_enqueue_script( 'slick', get_template_directory_uri().'/assets/js/slick/slick.min.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
                // Slick jQuery
                wp_enqueue_script( 'slick.js', get_template_directory_uri().'/assets/js/slick/slick.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'review' ){

                wp_enqueue_script( 'review', get_template_directory_uri().'/assets/js/review/jquery.rateyo.min.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'select2' ){

                /** CDN Link : http://cdnjs.cloudflare.com/ajax/libs/select2/3.2/select2.min.js **/
                wp_enqueue_script( 'select2', get_template_directory_uri().'/assets/js/select2/jQuery-select2.js', array('jquery'), self::fixit_details('fixit_version'), 'all' );
            }
            elseif( $args2 === 'color-picker' ){

                wp_enqueue_script( 'wp-color-picker' );
            }
            elseif( $args2 === 'google-map-api' ){

                // Check Google Map API Exists in Theme Option.
                if( mh_get_option('google_map_api_key') != '' ){
                    wp_enqueue_script( "fixit-google-map", "https://maps.googleapis.com/maps/api/js?key=". esc_attr( mh_get_option( self::fixit_prefix().'google_map_api_key') ) ."" , array('jquery'), self::fixit_details('fixit_version'), 'all' );
                }
            }
            elseif( $args2 === 'fixit_theme_script' ){

                if( is_rtl() ){
                    // Custom Style 
                    wp_enqueue_script( 'fixit-script', get_template_directory_uri(). self::fixit_directory( 'assets' ). 'js/rtl-script.js', array('jquery'), self::fixit_details('fixit_version'), true );
                }else{
                    // Custom Script 
                    wp_enqueue_script( 'fixit-script', get_template_directory_uri(). self::fixit_directory( 'assets' ). 'js/script.js', array('jquery'), self::fixit_details('fixit_version'), true );
                }
            }else{  return false;  }

        }else{ return false; }
    }

    public static function fixit_prefix(){

        return;
    }

} // END CLASS
