<?php
/**
 *    Theme options Backup File
 */

if( !defined( 'ABSPATH' ) ) exit;
if( !class_exists( 'Mh_Theme_Options_Backup' ) ) :

class Mh_Theme_Options_Backup {
    /**
	 * Protected variable.
	 */
    protected $mh_backup_page = "";
	/**
	 * Construct.
	 */
	public function __construct(){
		add_action( 'admin_init', array( $this ,'mh_theme_options_backup_page_setting' ) );
		add_action( 'admin_menu', array( $this ,'mh_backup_page' ) );
		add_action( 'admin_init', array( $this, 'mh_theme_options_import' ) );
		add_action( 'admin_init', array( $this, 'mh_theme_options_export' ) );
	}	
	/** 
	 * Register Setting.
	 */
	public function mh_theme_options_backup_page_setting(){
		register_setting( 'mh_options_group', 'mh_options' );
	}
	/**
	 * Add Theme Page Or Menu.
	 */
	public function mh_backup_page(){

		add_theme_page( 

			Fixit_Factory::fixit_details('theme_name'),
			Fixit_Factory::fixit_admin_page('_backup_option_title'),
			'manage_options',
			Fixit_Factory::fixit_admin_page('_backup_option_slug'),
			array( $this,'mh_backup_option_page')
		);
	}
	/**
	 * Main Admin page.
	 */
	public function mh_backup_option_page(){
	?>  
	<div class="wrap">
		<div class="metabox-holder">
			<div class="postbox">
			    <h3><span><?php _e( 'Export Settings', 'ac-repair'); ?></span></h3>
			    <div class="inside">
			        <p><?php _e( 'Export the plugin settings for this site as a .json file. This allows you to easily import the configuration into another site.', 'ac-repair' ); ?></p>
			        <form method="post">
			            <p><input type="hidden" name="mh_theme_options_action" value="export_settings" /></p>
			            <p>
			                <?php wp_nonce_field( 'mh_theme_options_export_nonce', 'mh_theme_options_export_nonce' ); ?>
			                <?php submit_button( __( 'Export', 'ac-repair' ), 'secondary', 'submit', false ); ?>
			            </p>
			        </form>
			    </div>
			</div>
			<div class="postbox">
			    <h3><span><?php _e( 'Fixit - Import Settings', 'ac-repair' ); ?></span></h3>
			    <div class="inside">
			    	<p><?php _e( 'Import the Theme options All Field values settings from a .json file.', 'ac-repair' ); ?></p>
			        <form method="post" enctype="multipart/form-data">
			            <p>
			                <input type="file" name="import_file"/>
			            </p>
			            <p>
			                <input type="hidden" name="mh_theme_options_action" value="import_settings" />
			                <?php wp_nonce_field( 'mh_theme_options_import_nonce', 'mh_theme_options_import_nonce' ); ?>
			                <?php submit_button( __( 'Import', 'ac-repair' ), 'secondary', 'submit', false ); ?>
			            </p>
			        </form>
			    </div>
			</div>
		</div>
	</div>
    <?php
	}	
	
	/**
	 * Process a settings export that generates a .json file of the shop settings
	 */
	public function mh_theme_options_export() {
		if( empty( $_POST['mh_theme_options_action'] ) || 'export_settings' != $_POST['mh_theme_options_action'] )
			return;
		if( ! wp_verify_nonce( $_POST['mh_theme_options_export_nonce'], 'mh_theme_options_export_nonce' ) )
			return;
		if( ! current_user_can( 'manage_options' ) )
			return;
		$settings = get_option( 'mh_options' );
		ignore_user_abort( true );
		nocache_headers();
		header( 'Content-Type: application/json; charset=utf-8' );
		header( 'Content-Disposition: attachment; filename='. Fixit_Factory::fixit_details('theme_name') .'-setting-export-' . date('d-m-Y').'.json' );
		header( "Expires: 0" );
		echo json_encode( $settings );
		exit;
	}

	/**
	 * Process a settings import from a json file
	 */
	public function mh_theme_options_import() {
		if( empty( $_POST['mh_theme_options_action'] ) || 'import_settings' != $_POST['mh_theme_options_action'] )
			return;
		if( ! wp_verify_nonce( $_POST['mh_theme_options_import_nonce'], 'mh_theme_options_import_nonce' ) )
			return;
		if( ! current_user_can( 'manage_options' ) )
			return;

		$filename = $_FILES['import_file']['name'];
		$extension = pathinfo( $filename, PATHINFO_EXTENSION );
		
		if( $extension != 'json' ) {
			wp_die( __( 'Please upload a valid .json file', 'ac-repair' ) );
		}
		$import_file = $_FILES['import_file']['tmp_name'];
		if( empty( $import_file ) ) {
			wp_die( __( 'Please upload a file to import', 'ac-repair' ) );
		}

		// Retrieve the settings from the file and convert the json object to an array.

		$lines = file( $import_file );
		foreach ($lines as $line_num => $line) 
		    $file_data .= $line;
		
		$settings = (array) json_decode( $file_data );
		update_option( 'mh_options', $settings );
		Fixit_Factory::fixit_redirect_page( 'theme-options' );
	}
	
}
endif;
/** 
 * $obj using class contstruct.
 */
$obj = new Mh_Theme_Options_Backup;
?>