<?php

/**
 *   Customization Code here.
 */

if ( ! defined( 'ABSPATH' ) ) exit;

if( ! function_exists( 'mh_theme_customizer' ) && function_exists( 'mh_theme_options' ) ) {

	function mh_theme_customizer( $wp_customize ) { 

		/**
		 *   Customizer Typography Control.
		 */
		class Customizer_Typography_Control extends WP_Customize_Control {
			public $fieldwidth = 'text';
			public $type = 'number';
		
			protected function render() {
				$id = 'customize-control-' . str_replace( '[', '-', str_replace( ']', '', $this->id ) );
				$class = 'customize-control customize-control-' . $this->type; ?>
				<li id="<?php echo esc_attr( $id, 'ac-repair' ); ?>" class="<?php echo esc_attr( $class, 'ac-repair' ); ?>" 
				style="clear:both;display:inline-block; width:80%;">
					<?php $this->render_content(); ?>
				</li>
			<?php }
		
			public function render_content() { ?>
				<label class="inline">
					<span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
					<input type="number" <?php $this->link(); ?> value="<?php echo intval( $this->value() ); ?>" />
				</label>
			<?php }
		}
	
		/** 
		 *    Customizer Radio Control.
		 */
		class Customizer_Radio_Control extends WP_Customize_Control {
		   public function render_content()  {
			if ( empty( $this->choices ) )
				return;
			$name = '_customize-radio-' . $this->id;
			if ( ! empty( $this->label ) ) : ?>
				<span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
			<?php endif;
			if ( ! empty( $this->description ) ) : ?>
				<span class="description customize-control-description"><?php echo $this->description ; ?></span>
			<?php endif;
			foreach ( $this->choices as $value => $label ) : ?>
				<label>
					<input type="radio" value="<?php echo esc_attr( $value, 'ac-repair' ); ?>" 
					name="<?php echo esc_attr( $name, 'ac-repair' ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
					<?php print $label; ?>
				</label>
				<?php
			endforeach;
			}
		}

		/** 
		 *    Customizer Checkbox Control.
		 */
		class Customizer_Checkbox_Control extends WP_Customize_Control {

		   public function render_content()  {

			$name = '_customize-checkbox-' . $this->id;
			if ( ! empty( $this->label ) ) : ?>
				<span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
			<?php endif;
			if ( ! empty( $this->description ) ) : ?>
				<span class="description customize-control-description"><?php echo $this->description ; ?></span>
			<?php endif;
			?>
				<label class="checkbox-switch">
					<input type="checkbox" value="<?php echo esc_attr( $value, 'ac-repair' ); ?>" 
					name="<?php echo esc_attr( $name, 'ac-repair' ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
					<?php print $label; ?>
				<div class="checkbox-slider checkbox-round"></div></label>
				<?php
			}
		}		
	
		/**
		 *     Customizer Multiple Select Option Control.
		 */
		class Customize_Multiple_Select_Control extends WP_Customize_Control {

		    public $type = 'multiselect';

		    public function render_content() {

		    if ( empty( $this->choices ) )
		        return;
		    ?>
		        <label>
		            <span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
		            <select <?php $this->link(); ?> multiple="multiple" style="height: 100%;">
		                <?php
		                    foreach ( $this->choices as $value => $label ) {
		                        $selected = ( in_array( $value, $this->value() ) ) ? selected( 1, 1, false ) : '';
		                        echo '<option value="' . esc_attr( $value, 'ac-repair' ) . '"' . $selected . '>' . $label . '</option>';
		                    }
		                ?>
		            </select>
		        </label>
		    <?php }
		}

		/**
		 *  Customizer Date-picker Control.
		 */
		class Customizer_Date_Picker_Control extends WP_Customize_Control{

			public function enqueue(){
			    wp_enqueue_style( 'jquery-ui-datepicker' );
			}
			public function render_content(){
			    ?>
			        <label>
			          <span class="customize-date-picker-control"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
			          <input type="date" id="<?php echo $this->id; ?>" name="<?php echo $this->id; ?>" <?php $this->link(); ?> value="<?php echo $this->value(); ?>" class="" />
			        </label>
			    <?php
			}
		}
		
		/**
		 *  Customizer Range-Validator Control.
		 */
		class Customization_Range_Validator_Control extends WP_Customize_Control{
			public function render_content(){
			?>
				<span class="slider-range-validator-class">
					<span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
					<input type="number" <?php $this->link(); ?>  value="<?php echo $this->value(); ?>" style="width:50%;"  />
					<input type="range" step="1"  value="<?php echo $this->value(); ?>" <?php $this->link(); ?> style="width:90%;" >
				</span>	
			<?php
			}
		}

		/**
		 *  Customization Google Map
		 */
		class Customizer_Google_Map_Control extends WP_Customize_Control {
			public function render_content(){
			    ?>
			        <label>
			          <span class="customize-control-title"><?php echo esc_html( $this->label, 'ac-repair' ); ?></span>
			          <div style="height: 350px;width: 100%;" id="<?php echo $this->id; ?>" <?php $this->link(); ?>></div>
			        </label>
			    <?php
			}
		}

		/**
		 *  Customization Array pass a value.
		 */
		$mh_options = mh_theme_options();	

	    foreach ( $mh_options as $value ) :
			switch( $value['type'] ) :

				case "section" :
					$wp_customize->add_section( $value['name'], array(
						'title' 		=> $value['name'],
						'description' 	=> $value['description'],
						'priority' 		=> $value['priority'],
					) );
				break;
				case "text" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
						'transport'   		=> 'postMessage',
					) );
					$wp_customize->add_control( 'mh_options_'.$value['id'] , array(
						'label' 		=> $value['name'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id'].']',
						'type' 			=> $value['type'],

					) );			
				break;
				case "margin" :
					$wp_customize->add_setting( 'mh_options['.$value['id_1'].']', array(
						'default' 		=> $value['default_1'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_1'], array (
						'label'    		=> $value['label_1'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_1'].']',
						'type'      	=> 'number',
						'fieldwidth'	=> absint('50'), //set the field to 50% width so that we can display a second one next to it
					) ) );
					$wp_customize->add_setting( 'mh_options['.$value['id_2'].']', array(
						'default' 		=> $value['default_2'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_2'], array (
						'label'    		=> $value['label_2'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_2'].']',
						'type'      	=> 'number',
						'fieldwidth'	=> absint('50'), //set the field to 50% width so that we can display a second one next to it
					) ) );
					$wp_customize->add_setting( 'mh_options['.$value['id_3'].']', array(
						'default' 		=> $value['default_3'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_3'], array (
						'label'    		=> $value['label_3'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_3'].']',
						'type'      	=> 'number',
						'fieldwidth'	=> absint('50'), //set the field to 50% width so that we can display a second one next to it
					) ) );
					$wp_customize->add_setting( 'mh_options['.$value['id_4'].']', array(
						'default' 		=> $value['default_4'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_4'], array (
						'label'    		=> $value['label_4'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_4'].']',
						'type'      	=> 'number',
						'fieldwidth'	=> absint('50'), //set the field to 50% width so that we can display a second one next to it
					) ) );
				break;					
				case "map" :
					$wp_customize->add_setting( 'mh_options['.$value['id_1'].']', array(
						'default' 		=> $value['default_1'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( 'mh_options_'.$value['id_1'] , array(
						'label' 		=> mh_customizer_string_combine( $value['name'], $value['label_1'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_1'].']',
						'type' 			=> $value['type'],
						'input_attrs' => array(
					        'class'   => 'MapLat',
					    ),
					) );
					$wp_customize->add_setting( 'mh_options['.$value['id_2'].']', array(
						'default' 		=> $value['default_2'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( 'mh_options_'.$value['id_2'] , array(
						'label' 		=> mh_customizer_string_combine( $value['name'], $value['label_2'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_2'].']',
						'type' 			=> $value['type'],
						'input_attrs' => array(
					        'class'   => 'MapLon',
					    ),
					) );
					$wp_customize->add_setting( 'mh_options[map_canvas]', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Google_Map_Control( $wp_customize, 'map_canvas', array(
						'label' 		=> $value['name'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options[map_canvas]',
						'type' 			=> $value['type'],
					) ) );
				break;
				case "date-picker":
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Date_Picker_Control( $wp_customize, 'mh_options_'.$value['id'] , array(
						'label' 		=> $value['name'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id'].']',
						'type' 			=> 'date',
					) ) );
				break;
				case "textarea" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( 'mh_options_'.$value['id'], array(
						'label' 		=> $value['name'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id'].']',
						'type' 			=> 'textarea',
					) );	
				break;
				case "radio" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));
					$wp_customize->add_control( new Customizer_Radio_Control($wp_customize, 'mh_options_'.$value['id'], array(
						'label'    		=> $value['name'],
						'section'    	=> $value['section'],
						'settings'   	=> 'mh_options['.$value['id'].']',
						'type'       	=> 'radio',
						'choices'    	=> $value['options'],
						'transport'   	=> 'postMessage',
					) ) );
				break;
				case "checkbox" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']' , array(
						'capability' 	=> 'edit_theme_options',
						'type'       	=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));
					$wp_customize->add_control( new Customizer_Checkbox_Control($wp_customize, 'mh_options_'.$value['id'], array(
						'label'    		=> $value['name'],
						'settings' 		=> 'mh_options['.$value['id'].']',
						'section'  		=> $value['section'],
						'type'    		=> 'checkbox',
					) ) );
				break;
				case "select" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));	
					$wp_customize->add_control('mh_options_'.$value['id'], array(
						'settings' 		=> 'mh_options['.$value['id'].']',
						'label'    		=> $value['name'],
						'section'  		=> $value['section'],
						'type'     		=> 'select',
						'choices'		=> $value['options'],
					));
				break;
				case "multiselect" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));	
					$wp_customize->add_control( new Customize_Multiple_Select_Control( $wp_customize, 'mh_options_'.$value['id'], array(
			            'settings' 		=> 'mh_options['.$value['id'].']',
			            'label'    		=> $value['name'],
			            'section'  		=> $value['section'],
			            'type'     		=> 'multiselect',
			            'choices' 		=> $value['options'],
					)));
				break;
				case "image" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));			
					$wp_customize->add_control( new WP_Customize_Upload_Control( $wp_customize, 'mh_options_'.$value['id'] , array(
						'label' 		=> $value['name'],
						'section' 		=> $value['section'],
						'settings'		=> 'mh_options['.$value['id'].']',
					)));
				break;
				case "color" :		
					$wp_customize->add_setting('mh_options['.$value['id'].']', array(
						'default' 			=> $value['default'],
						'sanitize_callback' => 'sanitize_hex_color',
						'capability'        => 'edit_theme_options',
						'type'           	=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
						'transport'   		=> 'postMessage',
					));
					$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mh_options_'.$value['id'], array(
						'label'    			=> $value['name'],
						'section'  			=> $value['section'],
						'settings' 			=> 'mh_options['.$value['id'].']',
					)));		
				break;
				case "color_2":
					$wp_customize->add_setting('mh_options['.$value['id_1'].']', array(
						'default'           => '',
						'sanitize_callback' => 'sanitize_hex_color',
						'capability'        => 'edit_theme_options',
						'type'           	=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
						'transport'   		=> 'postMessage',
					));
					$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mh_options_'.$value['id_1'], array(
						'label'    			=> mh_customizer_string_combine( $value['name'], $value['label_1'] ),
						'section'  			=> $value['section'],
						'settings' 			=> 'mh_options['.$value['id_1'].']',
					)));
					$wp_customize->add_setting('mh_options['.$value['id_2'].']', array(
						'default'           => '',
						'sanitize_callback' => 'sanitize_hex_color',
						'capability'        => 'edit_theme_options',
						'type'           	=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
						'transport'   		=> 'postMessage',
					));
					$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mh_options_'.$value['id_2'], array(
						'label'    			=> mh_customizer_string_combine( $value['name'], $value['label_2'] ),
						'section'  			=> $value['section'],
						'settings' 			=> 'mh_options['.$value['id_2'].']',
					)));		
				break;
				case "spinner" :
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id'], array (
						'label'    		=> $value['name'],
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id'].']',
						'type'      	=> 'number',			
						'fieldwidth'	=> $value['style'],
					) ) );	
				break;
				case "range-validator":
					$wp_customize->add_setting( 'mh_options['.$value['id'].']', array(
						'default' 		=> $value['default'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customization_Range_Validator_Control( $wp_customize, 'mh_options['.$value['id'].']', array(
					    'type'        => 'range',
					    'section'     => $value['section'],
					    'label'       => $value['name'],
					    'input_attrs' => array(
					        'min'     => 0,
					        'max'     => 100,
					        'step'    => 1,
					        'style'   => 'color: #0a0; width:100%;',
					    ),
					) ) );
				break;
				case "typography" :
					$wp_customize->add_setting( 'mh_options['.$value['id_1'].']', array(
						'default' 		=> $value['default_1'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_1'], array (
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_1'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_1'].']',
						'type'      	=> 'number',			
						'fieldwidth'	=> '50', 
					) ) );			
					$wp_customize->add_setting( 'mh_options['.$value['id_2'].']', array(
						'default' 		=> $value['default_2'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_2'], array (
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_2'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_2'].']',
						'type'      	=> 'number',			
						'fieldwidth'	=> '50',
					) ) );
					$wp_customize->add_setting( 'mh_options['.$value['id_3'].']', array(
						'default' 		=> $value['default_3'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));	
					$wp_customize->add_control('mh_options_'.$value['id_3'], array(
						'settings' 		=> 'mh_options['.$value['id_3'].']',
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_3'] ),
						'section'  		=> $value['section'],
						'type'     		=> 'select',
						'choices'		=> $value['options_3'],
					));
					$wp_customize->add_setting('mh_options['.$value['id_4'].']', array(
						'default'           => '',
						'sanitize_callback' => 'sanitize_hex_color',
						'capability'        => 'edit_theme_options',
						'type'           	=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
						'transport'   		=> 'postMessage',
					));
					$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'mh_options_'.$value['id_4'], array(
						'section'  		=> $value['section'],
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_4'] ),
						'settings' 		=> 'mh_options['.$value['id_4'].']',
					)));
				break;
				case "body_typography" :
					$wp_customize->add_setting( 'mh_options['.$value['id_1'].']', array(
						'default' 		=> $value['default_1'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));	
					$wp_customize->add_control('mh_options_'.$value['id_1'], array(
						'settings' 		=> 'mh_options['.$value['id_1'].']',
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_1'] ),
						'section'  		=> $value['section'],
						'type'     		=> 'select',
						'choices'		=> $value['options_1'],
					));
					$wp_customize->add_setting( 'mh_options['.$value['id_2'].']', array(
						'default' 		=> $value['default_2'],
						'capability'    => 'edit_theme_options',
						'type'          => 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					));	
					$wp_customize->add_control('mh_options_'.$value['id_2'], array(
						'settings' 		=> 'mh_options['.$value['id_2'].']',
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_2'] ),
						'section'  		=> $value['section'],
						'type'     		=> 'select',
						'choices'		=> $value['options_2'],
					));			
					$wp_customize->add_setting( 'mh_options['.$value['id_3'].']', array(
						'default' 		=> $value['default_3'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_3'], array (
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_3'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_3'].']',
						'type'      	=> 'number',			
						'fieldwidth'	=> '50',
					) ) );
					$wp_customize->add_setting( 'mh_options['.$value['id_4'].']', array(
						'default' 		=> $value['default_4'],
						'type' 			=> 'option',
						'sanitize_callback' => 'fixit_function_sanitize_callback',
					) );
					$wp_customize->add_control( new Customizer_Typography_Control( $wp_customize, 'mh_options_'.$value['id_4'], array (
						'label'    		=> mh_customizer_string_combine( $value['name'], $value['label_4'] ),
						'section' 		=> $value['section'],
						'settings' 		=> 'mh_options['.$value['id_4'].']',
						'type'      	=> 'number',			
						'fieldwidth'	=> '50',
					) ) );			
				break;
				default :  break;	

			endswitch;	
		endforeach;


		/**
		 *  Customizer tools
		 */
		add_action('customize_controls_print_styles', 'fixit_live_customizer_css' );

		function fixit_live_customizer_css(){

			print '<style type="text/css"> /** on/off button **/
.customize-control-checkbox label.checkbox-switch{ padding-top:0px; padding-bottom:0px; margin-left:0px; }
.checkbox-switch{position:relative;display:inline-block;width:60px;height:34px}
.checkbox-switch input{display:none}
.checkbox-slider{position:absolute;cursor:pointer;top:0;left:0;right:0;bottom:0;background-color:#ccc;-webkit-transition:.4s;transition:.4s}
.checkbox-slider:before{position:absolute;content:"";height:26px;width:26px;left:4px;bottom:4px;background-color:#fff;-webkit-transition:.4s;transition:.4s}
input:checked+.checkbox-slider{background-color:#2196F3}
input:focus+.checkbox-slider{box-shadow:0 0 1px #2196F3}
input:checked+.checkbox-slider:before{-webkit-transform:translateX(26px);-ms-transform:translateX(26px);transform:translateX(26px)}
.checkbox-slider.checkbox-round{border-radius:34px}
.checkbox-slider.checkbox-round:before{border-radius:50%} </style>';

		}

		add_action( 'wp_footer', 'fixit_live_customizer_js', 30 );

		function fixit_live_customizer_js(){  

		$mh_options = mh_theme_options();	
		?> <script type="text/javascript"> (function( $ ) { "use strict";  <?php

		    foreach ( $mh_options as $value ) :
				switch( $value['type'] ) :

					case "color" : ?>
					wp.customize( '<?php print 'mh_options['.$value['id'].']'; ?>' , function( value ) {
						value.bind( function( to ) {
							<?php if( $value['customizer'] != '' && is_array( $value['customizer'] ) ) { foreach( $value['customizer'] as $css_key => $css_value) { ?>
								if( $('<?php print $css_key;  ?>').length ){
									$('<?php print $css_key; ?>').css( '<?php print $css_value; ?>', to );
								}
							<?php } } ?>
						});
					});
					<?php
					break;
					case "color_2" : ?>
					wp.customize( '<?php print 'mh_options['.$value['id_1'].']'; ?>' , function( value ) {
						value.bind( function( to ) {
							<?php if( $value['customizer_1'] != '' && is_array( $value['customizer_1'] ) ) {  foreach( $value['customizer_1'] as $css_key => $css_value) { ?>
								if( $('<?php print $css_key; ?>').length ){
									$('<?php print $css_key; ?>').css( '<?php print $css_value; ?>', to );
								}
							<?php } } ?>
						});
					});
					wp.customize( '<?php print 'mh_options['.$value['id_2'].']'; ?>' , function( value ) {
						value.bind( function( to ) {
							<?php if( $value['customizer_2'] != '' && is_array( $value['customizer_2'] ) ) {   foreach( $value['customizer_2'] as $css_key => $css_value) { ?>
								if( $('<?php print $css_key; ?>').length ){
									$('<?php print $css_key; ?>').css( '<?php print $css_values; ?>', to );
								}
							<?php } } ?>
						});
					});
					<?php
					break;
					case "typography" : ?>
					wp.customize( '<?php print 'mh_options['.$value['id_4'].']'; ?>' , function( value ) {
						value.bind( function( to ) {
							<?php if( $value['customizer_4'] != '' && is_array( $value['customizer_4'] ) ) {  foreach( $value['customizer_4'] as $css_key => $css_value) { ?>
								if( $('<?php print $css_key;  ?>').length ){
									$('<?php print $css_key; ?>').css( '<?php print $css_value; ?>', to );
								}
							<?php } } ?>
						});
					});
					<?php
					break;			
				endswitch;
			endforeach;

		?>})( jQuery ); </script><?php
		}

	} // end of customization.

	add_action( 'customize_register', 'mh_theme_customizer' ); 
}
?>