<?php
/**
 *  Admin init File.
 */

if( !defined( 'ABSPATH' ) ) exit;
if( !class_exists( 'Mh_Theme_Init' ) ) :

class Mh_Theme_Init {
    /**
	 * Protected variable.
	 */
    protected $mh_options_page = "";
	/**
	 * Construct.
	 */
	public function __construct(){
		add_action( 'admin_init', array( $this ,'mh_register_setting' ) );
		add_action( 'admin_menu', array( $this ,'mh_option_page' ) );
		add_action( 'wp_ajax_mh_admin_theme_options_reset', array( $this, 'mh_admin_theme_options_reset' ) );
	}	
	/** 
	 * Register Setting.
	 */
	public function mh_register_setting(){
		register_setting( 'mh_options_group', 'mh_options' );
	}
	/**
	 * Add Theme Page Or Menu.
	 */
	public function mh_option_page(){

		$this->mh_options_page  = add_theme_page( 

			Fixit_Factory::fixit_details('theme_name'),
			Fixit_Factory::fixit_admin_page('_theme_option_title'),
			'manage_options',
			Fixit_Factory::fixit_admin_page('_theme_option_slug'),
			array( $this,'mh_options_page')
		);

		add_action( 'admin_print_scripts-'.$this->mh_options_page, array( $this ,'mh_print_script_init' ) );
		add_action( 'admin_print_styles-' .$this->mh_options_page, array( $this ,'mh_print_style_init' ) );		
	}
	/** 
	 * Admin Page Script.
	 */
	public function mh_print_style_init() {
		
		Fixit_Factory::fixit_enqueue( 'style', 'color-picker' );
		Fixit_Factory::fixit_enqueue( 'style', 'bootstrap' );
		Fixit_Factory::fixit_enqueue( 'style', 'bootstrap-vertical-tabs' );
		if( ! class_exists('WooCommerce') )
			Fixit_Factory::fixit_enqueue( 'style', 'select2' );
	}
	public function mh_print_script_init() {

		Fixit_Factory::fixit_enqueue( 'script', 'color-picker' );
		Fixit_Factory::fixit_enqueue( 'script', 'bootstrap' );
		if( ! class_exists('WooCommerce') ) 
			Fixit_Factory::fixit_enqueue( 'script', 'select2' );
		wp_enqueue_script('framework-script', FIXIT_FRAMEWORK_DIR . '/js/script.js', array('jquery'), true );
	}
	/**
	 * Main Admin page.
	 */
	public function mh_options_page(){
	?>
  	<div class="theme_wrapper">
    	<?php settings_errors();  ?>
   		<div id="savemessage"></div>
	</div>
	<div id="theme-options-page" class="theme_wrapper theme_option">
	  <div class="container-fluid">	
	    <div class="page-header mt30">
	      <h1><?php esc_html_e('Ac Repair','ac-repair');  ?><small><?php print '&nbsp;&nbsp;Version.'.Fixit_Factory::fixit_details( 'fixit_version' );;  ?></small></h1>
	    </div>
	    <div class="row to-wrapper">
	      <div id="to-wrapper">
	        <div class="col-lg-2 col-md-2 col-sm-4 col-xs-12">
	          <ul class="nav nav-tabs tabs-left">
	            <?php echo mh_theme_options_tab_menu(); ?>
	          </ul>
	        </div>
	        <div class="col-lg-10 col-md-10 col-sm-8 col-xs-12 border_style">
	          <div class="to-content">
	            <!-- Tab panes --> 
	            <form action='options.php' method='post' class="form-horizontal" id="mh-theme-options-form">
	              <?php settings_fields( 'mh_options_group' ); ?>
	              <?php do_settings_sections( 'mh_options_group' ); ?>
	              <div class="tab-content">
	                <?php echo mh_theme_options_tab_page(); ?>
	              </div>
	              <!-- tab-content -->                  
                  <div class="clear_fix"></div>
                  <div class="submit_div">                  
	              <p class="submit">
	                <input name="mh_options[submit]" type="submit" class="pull-right submit_bk_color ease_button" value="<?php esc_attr_e('Save Settings', 'ac-repair'); ?>" />
	                <input name="mh_options[reset]"  type="button" class="reset_bk_color ease_button" value="<?php esc_attr_e('Reset Defaults', 'ac-repair'); ?>" id="reset-button" />
	              </p>
                  </div>
                  <!-- submit_div -->
	            </form>
	          </div>
	        </div>
	      </div>
	    </div>
	  </div>
	</div>
    <?php
	}
	
	/**
	 * Reset admin options
	 */
	public function mh_admin_theme_options_reset(){
	
	   $mh_options = mh_theme_options(); $valid_input = array();
	   
	   foreach ( $mh_options as $value ) :				
	   switch ( true ):
			case ( $value['type'] == "text" ||  $value['type'] == "textarea" ||  $value['type'] == "checkbox" || 
				   $value['type'] == "radio" || $value['type'] == "select" || $value['type'] == "image" || 
				   $value['type'] == "color" || $value['type'] == "editor" || $value['type'] == "date-picker" ||
				   $value['type'] == "spinner" || $value['type'] == "range-validator" || $value['type'] == "multiselect" ) :
				   $valid_input[ $value['id'] ]  = empty( $value['default'] )  ? '' : $value['default'];
			break;
			case ( $value['type'] ==  "typography" ||  $value['type'] == "body_typography" || $value['type'] == "margin" ) :		
				  $valid_input[ $value['id_1'] ] = empty( $value['default_1'] ) ? '' : $value['default_1'];
				  $valid_input[ $value['id_2'] ] = empty( $value['default_2'] ) ? '' : $value['default_2'];
				  $valid_input[ $value['id_3'] ] = empty( $value['default_3'] ) ? '' : $value['default_3'];
				  $valid_input[ $value['id_4'] ] = empty( $value['default_4'] ) ? '' : $value['default_4'];
			break;	
			case ( $value['type'] == "color_2" ) :
				  $valid_input[ $value['id_1'] ] = empty( $value['default_1'] ) ? '' : $value['default_1'];
				  $valid_input[ $value['id_2'] ] = empty( $value['default_2'] ) ? '' : $value['default_2'];
			break;
			case ( $value['type'] == "map" ) :
				  $valid_input[ $value['id_1'] ] = empty( $value['default_1'] ) ? '' : $value['default_1'];
				  $valid_input[ $value['id_2'] ] = empty( $value['default_2'] ) ? '' : $value['default_2'];
				  $valid_input[ $value['id_3'] ] = empty( $value['default_3'] ) ? '' : $value['default_3'];
			break;
			default :  break;			
		endswitch;
		endforeach;
		update_option( 'mh_options', $valid_input );	
	}
}
endif;
/** 
 * $obj using class contstruct.
 */
$obj = new Mh_Theme_Init;

?>