<?php  

# -*- coding: utf-8 -*-
# Widget Name: Sidebar information widget

add_action( 'widgets_init', array ( 'Sidebar_Information', 'register' ) );

class Sidebar_Information extends WP_Widget {

    /**
     * Constructor.
     */
    public function __construct(){
        parent::__construct( strtolower( __CLASS__ ), esc_html('Fixit -- Sidebar Information Widget') );
    }

    /**
     * Echo the settings update form
     *
     * @param array $instance Current settings
     */
    public function form( $instance ){

        $title = isset ( $instance['title'] ) ? $instance['title'] : esc_html__('Fixit -- Sidebar Title', 'ac-repair');
        $title = esc_attr( $title );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><input type="text" name="%3$s" id="%1$s" value="%4$s" class="widefat"></p>',
            $this->get_field_id( 'title' ),
            esc_html__( 'Title', 'ac-repair' ),
            $this->get_field_name( 'title' ),
            esc_attr( $title )
        );

        $variable_list = fixit_function_font_awesome_icon_list();
        $font_key = $font_value = $option_key = '';

        $fontawesome = isset( $instance['fontawesome'] ) ? $instance['fontawesome'] : '';
        $fontawesome = esc_html( $fontawesome );

        foreach ($variable_list as $key => $value) {
            $font_key .= $key;
            $font_value .= $value;
            $option_key .= '<option data-icon="'.esc_html($key).'" value="'.esc_html($key).'" '. selected( $fontawesome == $key, true, false ) .' >'.esc_html($value).'</option>';
        }

        printf(
            '<p class=""><label for="%1$s">%2$s</label><br /><select name="%3$s" id="%1$s" class="widefat">%4$s</select></p>',
            $this->get_field_id( 'fontawesome' ),
            esc_html__('Choose your icon', 'ac-repair' ),
            $this->get_field_name( 'fontawesome' ),
            $option_key

        );

        $textarea = isset ( $instance['textarea'] ) ? $instance['textarea'] : esc_html__('Fixit -- Sidebar Your Descrition.', 'ac-repair' );
        $textarea = esc_attr( $textarea );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><textarea name="%3$s" id="%1$s" rows="7" class="widefat">%4$s</textarea>',
            $this->get_field_id( 'textarea' ),
            esc_html__( 'Description', 'ac-repair' ),
            $this->get_field_name( 'textarea' ),
            esc_attr( $textarea )
        );
    }

    /**
     * Renders the output.
     *
     * @see WP_Widget::widget()
     */
    public function widget( $args, $instance ){   // Widget output
       
        extract($args);

        $fontawesome = isset( $instance['fontawesome'] ) ? $instance['fontawesome'] : '';
        $title  = isset( $instance['title'] ) ? $instance['title'] : esc_html__('Fixit -- Sidebar Title', 'ac-repair');
        $textarea = isset( $instance['textarea'] ) ? $instance['textarea'] : esc_html__('Fixit -- your description.', 'ac-repair');
        $selected_icon = isset( $fontawesome ) ? '<i class="fa '.$fontawesome.'"></i>' : '';
        $fontawesome = esc_html( $fontawesome );

        print  $before_widget
            .  '<div class="widget-address">'.$selected_icon   
            .  $before_title
            .  esc_html( $title )
            .  $after_title
            .  fixit_function_strip_tags( $textarea )
            .  '</div>'
            .  $after_widget ;
    }

    /**
     * Prepares the content. Not.
     *
     * @param  array $new_instance New content
     * @param  array $old_instance Old content
     * @return array New content
     */
    public function update( $new_instance, $old_instance ){
        
        $new_instance_array = array( 'title', 'fontawesome', 'textarea' );
        foreach( $new_instance_array as $val )
            $old_instance[ $val ] = $new_instance[ $val ];
        return $old_instance;
    }

    /**
     * Tell WP we want to use this widget.
     *
     * @wp-hook widgets_init
     * @return void
     */
    public static function register(){
        register_widget( __CLASS__ );
    }
}