<?php  

# -*- coding: utf-8 -*-
# Widget Name: Sidebar information widget

add_action( 'widgets_init', array ( 'Testimonials_Sidebar_Widget', 'register' ) );

class Testimonials_Sidebar_Widget extends WP_Widget {

    /**
     * Constructor.
     */
    public function __construct(){
        parent::__construct( strtolower( __CLASS__ ), esc_html('Fixit -- Sidebar Testimonials Widget') );
    }

    /**
     * Echo the settings update form
     *
     * @param array $instance Current settings
     */
    public function form( $instance ){

        $testimonials_content = isset( $instance['testimonials_content'] ) ? $instance['testimonials_content'] : '&ldquo;Great experience from start to finish. Everyone that I dealt with was friendly and professional. Reliable and reasonable. I highly recommend them.&rdquo;';
        $testimonials_content = esc_html( $testimonials_content );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><textarea name="%3$s" id="%1$s" rows="7" class="widefat">%4$s</textarea>',
            $this->get_field_id( 'testimonials_content' ),
            esc_html__( 'Testimonials Content Here', 'ac-repair' ),
            $this->get_field_name( 'testimonials_content' ),
            esc_attr( $testimonials_content )
        );

        $testimonials_rating = isset( $instance['testimonials_rating'] ) ? $instance['testimonials_rating'] : '5';
        $testimonials_rating = esc_html( $testimonials_rating );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><input type="text" name="%3$s" id="%1$s" value="%4$s" class="widefat"></p>',
            $this->get_field_id( 'testimonials_rating' ),
            esc_html__( 'Enter Your Testimonials Rating Mimimum 1 and Maximam 5', 'ac-repair' ),
            $this->get_field_name( 'testimonials_rating' ),
            esc_attr( $testimonials_rating )
        );

        $testimonials_author_name = isset( $instance['testimonials_author_name'] ) ? $instance['testimonials_author_name'] : 'Charlotte Schardt';
        $testimonials_author_name = esc_html( $testimonials_author_name );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><input type="text" name="%3$s" id="%1$s" value="%4$s" class="widefat"></p>',
            $this->get_field_id( 'testimonials_author_name' ),
            esc_html__( 'Enter Your Testimonials Author name with Date or post', 'ac-repair' ),
            $this->get_field_name( 'testimonials_author_name' ),
            esc_attr( $testimonials_author_name )
        );

        $testimonials_post_date = isset( $instance['testimonials_post_date'] ) ? $instance['testimonials_post_date'] : 'July 12, 2017';
        $testimonials_post_date = esc_html( $testimonials_post_date );
        printf(
            '<p><label for="%1$s">%2$s</label><br /><input type="text" name="%3$s" id="%1$s" value="%4$s" class="widefat"></p>',
            $this->get_field_id( 'testimonials_post_date' ),
            esc_html__( 'Enter Your Testimonials post date', 'ac-repair' ),
            $this->get_field_name( 'testimonials_post_date' ),
            esc_attr( $testimonials_post_date )
        );        
    }

    public function star_rating( $args ){

        $star = '';

        for( $i = (int) absint($args); $i>= (int) absint('1'); $i-- )
            $star .= '<span class="star-done"><i class="fa fa-star"></i></span>';

        for( $j = (int) absint($args); $j< (int) absint('5'); $j++ )
            $star .= '<span class="star-done"><i class="fa fa-star-o"></i></span>';

        return $star;
    }

    /**
     * Renders the output.
     *
     * @see WP_Widget::widget()
     */
    public function widget( $args, $instance ){   // Widget output
       
        extract($args);

        $testimonials_content = isset( $instance['testimonials_content'] ) ? $instance['testimonials_content'] : '';
        $testimonials_content = esc_html( $testimonials_content );

        $testimonials_rating = isset( $instance['testimonials_rating'] ) ? $instance['testimonials_rating'] : '';
        $testimonials_rating = esc_html( $testimonials_rating );

        $testimonials_author_name = isset( $instance['testimonials_author_name'] ) ? $instance['testimonials_author_name'] : '';
        $testimonials_author_name = esc_html( $testimonials_author_name );

        $testimonials_post_date = isset( $instance['testimonials_post_date'] ) ? $instance['testimonials_post_date'] : '';
        $testimonials_post_date = esc_html( $testimonials_post_date );        

        // print  $before_widget .  $after_widget ;

        printf('<div class="col-md-12"><div class="testimonial-block outline pinside30 mb30">
                  <p class="testimonial-text"><i>%1$s</i></p>
                  <p class="star-rating">%2$s</p>
                  <div> <span class="testimonial-name">%3$s</span> - <span class="testimonial-date">%4$s</span></div>
               </div></div>', $testimonials_content, self::star_rating( $testimonials_rating ), $testimonials_author_name, $testimonials_post_date );
    }

    /**
     * Prepares the content. Not.
     *
     * @param  array $new_instance New content
     * @param  array $old_instance Old content
     * @return array New content
     */
    public function update( $new_instance, $old_instance ){
        
        $new_instance_array = array( 'testimonials_content', 'testimonials_rating', 'testimonials_author_name', 'testimonials_post_date' );
        foreach( $new_instance_array as $val )
            $old_instance[ $val ] = $new_instance[ $val ];
        return $old_instance;
    }

    /**
     * Tell WP we want to use this widget.
     *
     * @wp-hook widgets_init
     * @return void
     */
    public static function register(){
        register_widget( __CLASS__ );
    }
}